@@ -44,23 +44,21 @@
 #pod
 #pod C<Dist::Zilla::Tester::DieHard> (or, for brevity just C<DieHard>), is a replacement for
 #pod C<Dist::Zilla::Tester>. If C<Dist::Zilla> dies in construction, C<DieHard> catches the exception,
-#pod saves the exception and C<Dist::Zilla> logger, and returns "survivor" object.
+#pod saves the exception and C<Dist::Zilla> logger, and returns a "survivor" object.
 #pod
-#pod "Survivor" will fail in C<build> method: it just rethrows the saved exception. However, such
-#pod "delayed death" saves log messages for analysis:
+#pod Th returned survivor will fail in C<build> method: it just rethrows the saved exception. However,
+#pod such "delayed death" saves log messages for analysis:
 #pod
 #pod     my $tzil = Builder->from_config( … );
 #pod         # ^ Construction never fails,
 #pod         #   it always returns an object,
-#pod         #   either builder or stub.
+#pod         #   either builder or survivor.
 #pod     my $ex = exception { $tzil->build(); };
 #pod         # ^ Builder does build,
-#pod         #   stub rethrows exception.
+#pod         #   survivor rethrows the saved exception.
 #pod     is( $ex, $expected_exception, 'check status' );
-#pod         # ^ In any case we can check the exception.
 #pod     cmd_deeply( $tzil->log_messages, $expected_messages, 'check log messages' );
-#pod         # ^ In any case we can check log messages,
-#pod         #   even if Dist::Zilla dies in construction.
+#pod         # ^ In *any* case we can check log messages.
 #pod
 #pod =head1 NOTES
 #pod
@@ -80,7 +78,7 @@ package Dist::Zilla::Tester::DieHard;
 use Moose;
 
 # ABSTRACT: Die hard Dist::Zilla, but save the messages
-our $VERSION = '0.001'; # VERSION
+our $VERSION = '0.002'; # VERSION
 our $CLASS = __PACKAGE__;
 
 extends 'Dist::Zilla::Tester';
@@ -115,7 +113,7 @@ use Moose;
 use namespace::autoclean;
 
 ## no critic ( ProhibitReusedNames )
-our $VERSION = '0.001'; # VERSION
+our $VERSION = '0.002'; # VERSION
 ## critic ( ProhibitReusedNames )
 
 extends join( '::', qw{ Dist Zilla Tester _Builder } );
@@ -176,7 +174,7 @@ use Moose;
 use namespace::autoclean;
 
 ## no critic ( ProhibitReusedNames )
-our $VERSION = '0.001'; # VERSION
+our $VERSION = '0.002'; # VERSION
 ## critic ( ProhibitReusedNames )
 
 has exception => (              # Survivor stores the exception killed the buider
@@ -197,11 +195,9 @@ sub log_messages {              #   to have access to the log.
     return [ map( { $_->{ message } } @{ $self->logger->events } ) ];
 };
 
-sub build {                     #   Attempt to call `build` on stub rethrows the exception
+sub build {                     #   Attempt to call `build` on survivor rethrows the exception
     my ( $self ) = @_;          #   killed the builder.
-    my $exception = $self->exception . '';
-    chomp( $exception );
-    die "[DieHard] $exception\n";
+    die $self->exception;       ## no critic ( RequireCarping )
 };
 
 __PACKAGE__->meta->make_immutable;
@@ -254,7 +250,7 @@ __PACKAGE__->meta->make_immutable;
 #pod The approach works well, until C<Dist::Zilla> dies in C<from_config> (e. g. if a plugin throws an
 #pod exception in its construction).
 #pod
-#pod An straightforward attempt to catch exception thrown in C<from_config>:
+#pod A straightforward attempt to catch exception thrown in C<from_config>:
 #pod
 #pod     my $tzil;
 #pod     my $exception = exception { $tzil = Builder->from_config( … ); };
@@ -263,18 +259,18 @@ __PACKAGE__->meta->make_immutable;
 #pod     } else {
 #pod         like( $exception, qr{…}, 'status' );
 #pod     };
-#pod     cmd_deeply( $tzil->log_messages, $expected_messages, 'log messages' );
-#pod     #           ^^^^^ Oops: $tzil undefined.
-#pod     …
 #pod
 #pod works but… C<from_config> dies leaving C<$tzil> undefined, and C<log_messages> method call on
-#pod undefined value will definitely fail. C<Dist::Zilla> dies, and all the messages printed by either
-#pod C<Dist::Zilla> or its plugins die too.
+#pod undefined value will definitely fail:
+#pod
+#pod     cmd_deeply( $tzil->log_messages, $expected_messages, 'log messages' );
+#pod     #           ^^^^^^^^^^^^^^^^^^^ Oops: $tzil undefined.
+#pod
+#pod C<Dist::Zilla> dies, and all the messages logged by either C<Dist::Zilla> or its plugins die too.
 #pod
 #pod Using C<Dist::Zilla::Tester::DieHard> instead of regular C<Dist::Zilla::Tester> solves this
 #pod problem: even if a plugin throws an exception in constructor, C<< Builder->from_config >> does not
-#pod die but returns an object, a stub builder, which can be used to retrieve log messages by C<<
-#pod $tzil->log_messages >>.
+#pod die but returns a "survivor" object which can be used to retrieve log messages.
 #pod
 #pod =cut
 
@@ -295,7 +291,7 @@ Dist::Zilla::Tester::DieHard - Die hard Dist::Zilla, but save the messages
 
 =head1 VERSION
 
-Version 0.001, released on 2015-08-14 22:44 UTC.
+Version 0.002, released on 2015-08-15 13:26 UTC.
 
 =head1 WHAT?
 
@@ -321,23 +317,21 @@ Use C<Dist::Zilla::Tester::DieHard> instead of C<Dist::Zilla::Tester>:
 
 C<Dist::Zilla::Tester::DieHard> (or, for brevity just C<DieHard>), is a replacement for
 C<Dist::Zilla::Tester>. If C<Dist::Zilla> dies in construction, C<DieHard> catches the exception,
-saves the exception and C<Dist::Zilla> logger, and returns "survivor" object.
+saves the exception and C<Dist::Zilla> logger, and returns a "survivor" object.
 
-"Survivor" will fail in C<build> method: it just rethrows the saved exception. However, such
-"delayed death" saves log messages for analysis:
+Th returned survivor will fail in C<build> method: it just rethrows the saved exception. However,
+such "delayed death" saves log messages for analysis:
 
     my $tzil = Builder->from_config( … );
         # ^ Construction never fails,
         #   it always returns an object,
-        #   either builder or stub.
+        #   either builder or survivor.
     my $ex = exception { $tzil->build(); };
         # ^ Builder does build,
-        #   stub rethrows exception.
+        #   survivor rethrows the saved exception.
     is( $ex, $expected_exception, 'check status' );
-        # ^ In any case we can check the exception.
     cmd_deeply( $tzil->log_messages, $expected_messages, 'check log messages' );
-        # ^ In any case we can check log messages,
-        #   even if Dist::Zilla dies in construction.
+        # ^ In *any* case we can check log messages.
 
 =head1 WHY?
 
@@ -362,7 +356,7 @@ Usually I test my C<Dist::Zilla> plugins in such a way:
 The approach works well, until C<Dist::Zilla> dies in C<from_config> (e. g. if a plugin throws an
 exception in its construction).
 
-An straightforward attempt to catch exception thrown in C<from_config>:
+A straightforward attempt to catch exception thrown in C<from_config>:
 
     my $tzil;
     my $exception = exception { $tzil = Builder->from_config( … ); };
@@ -371,18 +365,18 @@ An straightforward attempt to catch exception thrown in C<from_config>:
     } else {
         like( $exception, qr{…}, 'status' );
     };
-    cmd_deeply( $tzil->log_messages, $expected_messages, 'log messages' );
-    #           ^^^^^ Oops: $tzil undefined.
-    …
 
 works but… C<from_config> dies leaving C<$tzil> undefined, and C<log_messages> method call on
-undefined value will definitely fail. C<Dist::Zilla> dies, and all the messages printed by either
-C<Dist::Zilla> or its plugins die too.
+undefined value will definitely fail:
+
+    cmd_deeply( $tzil->log_messages, $expected_messages, 'log messages' );
+    #           ^^^^^^^^^^^^^^^^^^^ Oops: $tzil undefined.
+
+C<Dist::Zilla> dies, and all the messages logged by either C<Dist::Zilla> or its plugins die too.
 
 Using C<Dist::Zilla::Tester::DieHard> instead of regular C<Dist::Zilla::Tester> solves this
 problem: even if a plugin throws an exception in constructor, C<< Builder->from_config >> does not
-die but returns an object, a stub builder, which can be used to retrieve log messages by C<<
-$tzil->log_messages >>.
+die but returns a "survivor" object which can be used to retrieve log messages.
 
 =head1 NOTES
 
